@@ -3,14 +3,15 @@ use strict;
 use warnings;
 use XSLoader;
 
-our $VERSION = '0.02';
+use AnyEvent;
+
+our $VERSION = '0.03';
 
 BEGIN {
-    $ENV{PERL_ANYEVENT_MODEL} = 'NSRunLoop';
+    push @AnyEvent::REGISTRY, [AnyEvent::Impl::NSRunLoop:: => AnyEvent::Impl::NSRunLoop::];
+    XSLoader::load __PACKAGE__, $VERSION;
 };
 
-XSLoader::load __PACKAGE__, $VERSION;
-
 sub io {
     my ($class, %arg) = @_;
 
